@@ -90,7 +90,10 @@ class Recipe(zc.recipe.egg.Eggs):
         for fn in MONGO_BINARIES:
             fullname = os.path.join(dst, 'bin', fn)
             if os.path.exists(fullname):
-                shutil.copy(fullname, bindir)
+                destfile = os.path.join(bindir, fn)
+                if os.path.exists(destfile):
+                    os.unlink(destfile)
+                os.symlink(fullname, bindir)
 
         for path in remove_after_install:
             shutil.rmtree(path)
